@@ -7,4 +7,4 @@ def record_variant_goal(request, experiment_id):
     if request.user.is_anonymous():
         user_id = request.session.get('bernoulli_id', None)
 
-    return record_goal_attained(settings.BERNOULLI_CLIENT_ID, experiment_id, user_id)
+    return record_goal_attained(client_id=settings.BERNOULLI_CLIENT_ID, experiment_id=experiment_id, user_id=user_id)
